@@ -2,7 +2,7 @@ package Test2::Harness::UI;
 use strict;
 use warnings;
 
-our $VERSION = '0.000026';
+our $VERSION = '0.000027';
 
 use Router::Simple;
 use Text::Xslate(qw/mark_raw/);
@@ -102,9 +102,6 @@ sub wrap {
         $controller = $class->new(request => $req, config => $self->{+CONFIG});
         $res = $controller->handle($r);
 
-        use Data::Dumper;
-        print Dumper($class, $res) unless blessed($res);
-
         1;
     };
     my $err = $@ || 'Internal Error';
@@ -123,7 +120,7 @@ sub wrap {
     my $ct = blessed($res) ? $res->content_type() : 'text/html';
     $ct ||= 'text/html';
     $ct = lc($ct);
-    $res->content_type('text/html') if blessed($res);
+    $res->content_type($ct) if blessed($res);
 
     if (my $stream = $res->stream) {
         return $stream;
